@@ -14,7 +14,7 @@ def main():
     parse.add_argument('-q', '--quote',action='store_true' ,help='random quotes nime', required=False)
     parse.add_argument('-c', '--char', help='get character info', nargs='+')
     parse.add_argument('--author', action='version', version='Kenzawa/Babwa')
-    parse.add_argument('-v', '--version', action='version', version='1.6.0')
+    parse.add_argument('-v', '--version', action='version', version='1.6.1')
     parse.add_argument('-nc', '--ncode', metavar='keyword', nargs='+', help='get ncode')
     parse.add_argument('-sn', '--seasonal', action='store_true', help='get title anime in specified seasonal')
 
@@ -124,7 +124,7 @@ def main():
     
     if args.seasonal:
         resultt = anipick.Seasonal(limit=5)
-        table = [['Year', resultt.year], ['Season', resultt.season], ['anime']]
+        table = [['Year', resultt.year], ['Season', resultt.season], ['anime', resultt.name]]
         if args.tablefmt:
                 print(tabulate.tabulate(table, tablefmt=args.tablefmt))
         else:
